@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -31,6 +31,7 @@ import java.io.Reader;
 import java.io.StringReader;
 import java.util.Arrays;
 import java.util.Vector;
+import java.util.stream.Collectors;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
@@ -39,13 +40,14 @@ import org.apache.tools.ant.Task;
 import org.apache.tools.ant.filters.util.ChainReaderHelper;
 import org.apache.tools.ant.types.FilterChain;
 import org.apache.tools.ant.util.ConcatFileInputStream;
+import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.KeepAliveOutputStream;
 import org.apache.tools.ant.util.LazyFileOutputStream;
 import org.apache.tools.ant.util.LeadPipeInputStream;
 import org.apache.tools.ant.util.LineOrientedOutputStreamRedirector;
+import org.apache.tools.ant.util.NullOutputStream;
 import org.apache.tools.ant.util.OutputStreamFunneler;
 import org.apache.tools.ant.util.ReaderInputStream;
-import org.apache.tools.ant.util.StringUtils;
 import org.apache.tools.ant.util.TeeOutputStream;
 
 /**
@@ -196,6 +198,11 @@ public class Redirector {
     /** Is the output binary or can we safely split it into lines? */
     private boolean outputIsBinary = false;
 
+    /** Flag which indicates if error and output files are to be discarded. */
+    private boolean discardOut = false;
+
+    private boolean discardErr = false;
+
     /**
      * Create a redirector instance for the given task
      *
@@ -441,6 +448,40 @@ public class Redirector {
         }
     }
 
+    /**
+     * Whether output should be discarded.
+     *
+     * <p>Defaults to false.</p>
+     *
+     * @param discard
+     *            if true output streams are discarded.
+     *
+     * @since Ant 1.10.10
+     * @see #setDiscardError
+     */
+    public void setDiscardOutput(final boolean discard) {
+        synchronized (outMutex) {
+            discardOut = discard;
+        }
+    }
+
+    /**
+     * Whether error output should be discarded.
+     *
+     * <p>Defaults to false.</p>
+     *
+     * @param discard
+     *            if true error streams are discarded.
+     *
+     * @since Ant 1.10.10
+     * @see #setDiscardOutput
+     */
+    public void setDiscardError(final boolean discard) {
+        synchronized (errMutex) {
+            discardErr = discard;
+        }
+    }
+
     /**
      * If true, (error and non-error) output will be "teed", redirected as
      * specified while being sent to Ant's logging mechanism as if no
@@ -533,6 +574,8 @@ public class Redirector {
      * <p>Binary output will not be split into lines which may make
      * error and normal output look mixed up when they get written to
      * the same stream.</p>
+     *
+     * @param b boolean
      * @since 1.9.4
      */
     public void setBinaryOutput(final boolean b) {
@@ -546,24 +589,12 @@ public class Redirector {
      *            contains the property value.
      * @param propertyName
      *            the property name.
-     *
-     * @exception IOException
-     *                if the value cannot be read form the stream.
      */
     private void setPropertyFromBAOS(final ByteArrayOutputStream baos,
-            final String propertyName) throws IOException {
-
-        final BufferedReader in = new BufferedReader(new StringReader(Execute
-                .toString(baos)));
-        String line = null;
-        final StringBuffer val = new StringBuffer();
-        while ((line = in.readLine()) != null) {
-            if (val.length() != 0) {
-                val.append(StringUtils.LINE_SEP);
-            }
-            val.append(line);
-        }
-        managingTask.getProject().setNewProperty(propertyName, val.toString());
+                                     final String propertyName) {
+        final BufferedReader in = new BufferedReader(new StringReader(Execute.toString(baos)));
+        managingTask.getProject().setNewProperty(propertyName,
+                in.lines().collect(Collectors.joining(System.lineSeparator())));
     }
 
     /**
@@ -582,7 +613,7 @@ public class Redirector {
             }
 
             if ((outputFilterChains != null && outputFilterChains.size() > 0)
-                    || !(outputEncoding.equalsIgnoreCase(inputEncoding))) {
+                    || !outputEncoding.equalsIgnoreCase(inputEncoding)) {
                 try {
                     final LeadPipeInputStream snk = new LeadPipeInputStream();
                     snk.setManagingComponent(managingTask);
@@ -624,7 +655,7 @@ public class Redirector {
             }
 
             if ((errorFilterChains != null && errorFilterChains.size() > 0)
-                    || !(errorEncoding.equalsIgnoreCase(inputEncoding))) {
+                    || !errorEncoding.equalsIgnoreCase(inputEncoding)) {
                 try {
                     final LeadPipeInputStream snk = new LeadPipeInputStream();
                     snk.setManagingComponent(managingTask);
@@ -671,10 +702,9 @@ public class Redirector {
                 } catch (final IOException eyeOhEx) {
                     throw new BuildException(eyeOhEx);
                 }
-                ((ConcatFileInputStream) inputStream)
-                        .setManagingComponent(managingTask);
+                ((ConcatFileInputStream) inputStream).setManagingComponent(managingTask);
             } else if (inputString != null) {
-                final StringBuffer buf = new StringBuffer("Using input ");
+                final StringBuilder buf = new StringBuilder("Using input ");
                 if (logInputString) {
                     buf.append('"').append(inputString).append('"');
                 } else {
@@ -704,10 +734,19 @@ public class Redirector {
 
     /** outStreams */
     private void outStreams() {
-        if (out != null && out.length > 0) {
-            final String logHead = new StringBuffer("Output ").append(
-                    ((appendOut) ? "appended" : "redirected")).append(" to ")
-                    .toString();
+        final boolean haveOutputFiles = out != null && out.length > 0;
+        if (discardOut) {
+            if (haveOutputFiles || outputProperty != null) {
+                throw new BuildException("Cant discard output when output or outputProperty"
+                        + " are set");
+            }
+            managingTask.log("Discarding output", Project.MSG_VERBOSE);
+            outputStream = NullOutputStream.INSTANCE;
+            return;
+        }
+        if (haveOutputFiles) {
+            final String logHead = "Output "
+                    + ((appendOut) ? "appended" : "redirected") + " to ";
             outputStream = foldFiles(out, logHead, Project.MSG_VERBOSE,
                     appendOut, createEmptyFilesOut);
         }
@@ -727,10 +766,19 @@ public class Redirector {
     }
 
     private void errorStreams() {
-        if (error != null && error.length > 0) {
-            final String logHead = new StringBuffer("Error ").append(
-                    ((appendErr) ? "appended" : "redirected")).append(" to ")
-                    .toString();
+        final boolean haveErrorFiles = error != null && error.length > 0;
+        if (discardErr) {
+            if (haveErrorFiles || errorProperty != null || logError) {
+                throw new BuildException("Cant discard error output when error, errorProperty"
+                        + " or logError are set");
+            }
+            managingTask.log("Discarding error output", Project.MSG_VERBOSE);
+            errorStream = NullOutputStream.INSTANCE;
+            return;
+        }
+        if (haveErrorFiles) {
+            final String logHead = "Error "
+                    + ((appendErr) ? "appended" : "redirected") + " to ";
             errorStream = foldFiles(error, logHead, Project.MSG_VERBOSE,
                     appendErr, createEmptyFilesErr);
         } else if (!(logError || outputStream == null) && errorProperty == null) {
@@ -983,22 +1031,10 @@ public class Redirector {
      */
     public void setProperties() {
         synchronized (outMutex) {
-            if (baos != null) {
-                try {
-                    baos.close();
-                } catch (final IOException eyeOhEx) {
-                    // Ignore exception
-                }
-            }
+            FileUtils.close(baos);
         }
         synchronized (errMutex) {
-            if (errorBaos != null) {
-                try {
-                    errorBaos.close();
-                } catch (final IOException eyeOhEx) {
-                    // Ignore exception
-                }
-            }
+            FileUtils.close(errorBaos);
         }
     }
 
