@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -28,6 +28,7 @@ import java.io.OutputStreamWriter;
 import java.io.PrintStream;
 import java.io.PushbackReader;
 import java.io.Serializable;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -38,7 +39,7 @@ import java.util.Properties;
 /**
  * <p>A Properties collection which preserves comments and whitespace
  * present in the input stream from which it was loaded.</p>
- * <p>The class defers the usual work of the <a href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>
+ * <p>The class defers the usual work of the <a href="https://docs.oracle.com/javase/8/docs/api/java/util/Properties.html">java.util.Properties</a>
  * class to there, but it also keeps track of the contents of the
  * input stream from which it was loaded (if applicable), so that it can
  * write out the properties in as close a form as possible to the input.</p>
@@ -145,7 +146,7 @@ public class LayoutPreservingProperties extends Properties {
     @Override
     public void load(final InputStream inStream) throws IOException {
         final String s = readLines(inStream);
-        final byte[] ba = s.getBytes(ResourceUtils.ISO_8859_1);
+        final byte[] ba = s.getBytes(StandardCharsets.ISO_8859_1);
         final ByteArrayInputStream bais = new ByteArrayInputStream(ba);
         super.load(bais);
     }
@@ -260,7 +261,7 @@ public class LayoutPreservingProperties extends Properties {
 
     @Override
     public void store(final OutputStream out, final String header) throws IOException {
-        final OutputStreamWriter osw = new OutputStreamWriter(out, ResourceUtils.ISO_8859_1);
+        final OutputStreamWriter osw = new OutputStreamWriter(out, StandardCharsets.ISO_8859_1);
 
         int skipLines = 0;
         final int totalLines = logicalLines.size();
@@ -315,7 +316,7 @@ public class LayoutPreservingProperties extends Properties {
      * @param is the stream from which to read the data
      */
     private String readLines(final InputStream is) throws IOException {
-        final InputStreamReader isr = new InputStreamReader(is, ResourceUtils.ISO_8859_1);
+        final InputStreamReader isr = new InputStreamReader(is, StandardCharsets.ISO_8859_1);
         final PushbackReader pbr = new PushbackReader(isr, 1);
 
         if (!logicalLines.isEmpty()) {
@@ -435,7 +436,7 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * Unescape the string according to the rules for a Properties
      * file, as laid out in the docs for <a
-     * href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>.
+     * href="https://docs.oracle.com/javase/8/docs/api/java/util/Properties.html">java.util.Properties</a>.
      * @param s the string to unescape (coming from the source file)
      * @return the unescaped string
      */
@@ -502,7 +503,7 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * Escape the string <code>s</code> according to the rules in the
      * docs for <a
-     * href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>.
+     * href="https://docs.oracle.com/javase/8/docs/api/java/util/Properties.html">java.util.Properties</a>.
      * @param s the string to escape
      * @return the escaped string
      */
@@ -513,7 +514,7 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * Escape the string <code>s</code> according to the rules in the
      * docs for <a
-     * href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>.
+     * href="https://docs.oracle.com/javase/8/docs/api/java/util/Properties.html">java.util.Properties</a>.
      * This method escapes all the whitespace, not just the stuff at
      * the beginning.
      * @param s the string to escape
@@ -526,7 +527,7 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * Escape the string <code>s</code> according to the rules in the
      * docs for <a
-     * href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>.
+     * href="https://docs.oracle.com/javase/8/docs/api/java/util/Properties.html">java.util.Properties</a>.
      * @param s the string to escape
      * @param escapeAllSpaces if <code>true</code> the method escapes
      * all the spaces, if <code>false</code>, it escapes only the
@@ -724,7 +725,7 @@ public class LayoutPreservingProperties extends Properties {
                 setValue(null);
             } else {
                 name = text.substring(0, pos);
-                setValue(text.substring(pos + 1, text.length()));
+                setValue(text.substring(pos + 1));
             }
             // trim leading whitespace only
             name = stripStart(name, " \t\f");
