@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,9 +22,7 @@ import org.apache.tools.ant.BuildFileRule;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-
-import static org.apache.tools.ant.AntAssert.assertContains;
-import static org.junit.Assert.fail;
+import org.junit.rules.ExpectedException;
 
 /**
  * Test that scripting selection works. Needs scripting support to work
@@ -34,6 +32,9 @@ public class ScriptSelectorTest {
     @Rule
     public BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException thrown = ExpectedException.none();
+
     @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/types/selectors/scriptselector.xml");
@@ -41,13 +42,9 @@ public class ScriptSelectorTest {
 
     @Test
     public void testNolanguage() {
-        try {
-            buildRule.executeTarget("testNolanguage");
-            fail("Absence of language attribute not detected");
-        } catch(BuildException ex) {
-            assertContains("script language must be specified", ex.getMessage());
-
-        }
+        thrown.expect(BuildException.class);
+        thrown.expectMessage("script language must be specified");
+        buildRule.executeTarget("testNolanguage");
     }
 
     @Test
